﻿using System;
using System.Collections.Generic;
using System.Data.Entity;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using ContactLibrary;
using DAL.Interfaces;
using DAL.Repositories;

namespace DAL
{
    public class UOW : IUOW, IDisposable
    {
        private readonly NLog.Logger _logger =
    NLog.LogManager.GetCurrentClassLogger();
        private readonly string _instanceId = Guid.NewGuid().ToString();
        // _logger.Info("InstanceId: " +_instanceId);


        private IDbContext DbContext { get; set; }
        protected IEFRepositoryProvider RepositoryProvider { get; set; }

        public UOW(IEFRepositoryProvider repositoryProvider, IDbContext dbContext)
        {
            _logger.Info("InstanceId: " + _instanceId);

            DbContext = dbContext;

            repositoryProvider.DbContext = dbContext;
            RepositoryProvider = repositoryProvider;
        }

        // UoW main feature - atomic commit at the end of work
        public void Commit()
        {
            ((DbContext)DbContext).SaveChanges();
        }

        //standard repos
        //public IEFRepository<Person> Persons { get { return GetStandardRepo<Person>(); } }
        public IEFRepository<Contact> Contacts { get { return GetStandardRepo<Contact>(); } }
        public IEFRepository<ContactType> ContactTypes { get { return GetStandardRepo<ContactType>(); } }

        // repo with custom methods
        // add it also in EFRepositoryFactories.cs, in method GetCustomFactories
        public IPersonRepository Persons { get { return GetRepo<IPersonRepository>(); } }

        // calling standard EF repo provider
        private IEFRepository<T> GetStandardRepo<T>() where T : class
        {
            return RepositoryProvider.GetRepositoryForEntityType<T>();
        }

        // calling custom repo provier
        private T GetRepo<T>() where T : class
        {
            return RepositoryProvider.GetRepository<T>();
        }

        #region IDisposable
        public void Dispose()
        {
            _logger.Info("InstanceId: " + _instanceId);
            Dispose(true);
            GC.SuppressFinalize(this);
        }
        protected virtual void Dispose(bool disposing)
        {
            _logger.Info("InstanceId: " + _instanceId+" disposing:"+disposing);
        }

        #endregion

    }
}
