﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Web.Http;
using System.Web.Http.Description;
using ContactLibrary;
using DAL;
using DAL.Interfaces;
using DAL.Repositories;

namespace WebApiApp.Controllers
{
    public class PeopleController : ApiController
    {
        private readonly NLog.Logger _logger = NLog.LogManager.GetCurrentClassLogger();
        private readonly string _instanceId = Guid.NewGuid().ToString();
        // _logger.Info("InstanceId: " +_instanceId);

        //private DataBaseContext db = new DataBaseContext();
        //private readonly PersonRepository _repoPerson = new PersonRepository(new DataBaseContext());

        private readonly IUOW _uow;

        public PeopleController(IUOW uow)
        {
            _logger.Info("InstanceId: " + _instanceId);

            _uow = uow;
        }

        // GET: api/People
        public IQueryable<Person> GetPersons()
        {
            return _uow.Persons.All;
        }

        // GET: api/People/5
        [ResponseType(typeof(Person))]
        public IHttpActionResult GetPerson(int id)
        {
            Person person = _uow.Persons.GetById(id);
            if (person == null)
            {
                return NotFound();
            }

            return Ok(person);
        }

        // PUT: api/People/5
        [ResponseType(typeof(void))]
        public IHttpActionResult PutPerson(int id, Person person)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            if (id != person.PersonID)
            {
                return BadRequest();
            }

            _uow.Persons.Update(person);
            try
            {
                _uow.Commit();
            }
            catch (DbUpdateConcurrencyException)
            {
                if (!PersonExists(id))
                {
                    return NotFound();
                }
                else
                {
                    throw;
                }
            }

            return StatusCode(HttpStatusCode.NoContent);
        }

        // POST: api/People
        [ResponseType(typeof(Person))]
        public IHttpActionResult PostPerson(Person person)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            _uow.Persons.Add(person);
            _uow.Commit();

            return CreatedAtRoute("DefaultApi", new { id = person.PersonID }, person);
        }

        // DELETE: api/People/5
        [ResponseType(typeof(Person))]
        public IHttpActionResult DeletePerson(int id)
        {
            Person person = _uow.Persons.GetById(id);
            if (person == null)
            {
                return NotFound();
            }

            _uow.Persons.Delete(person);
            _uow.Commit();

            return Ok(person);
        }

        protected override void Dispose(bool disposing)
        {
            _logger.Info("InstanceId: " + _instanceId+" disposing: "+disposing);
            base.Dispose(disposing);
        }

        private bool PersonExists(int id)
        {
            return _uow.Persons.All.Count(e => e.PersonID == id) > 0;
        }
    }
}